@@ -2,6 +2,8 @@
 import logging
 import os.path
 import pkgutil
+import importlib
+import sys
 from functools import reduce
 from typing import Callable, Dict, Generator, List, Optional, Tuple
 
@@ -15,6 +17,7 @@ from jinja2 import (
 )
 from jinja2.environment import Template
 from jinja2.exceptions import TemplateNotFound, UndefinedError
+from jinja2.ext import Extension
 from jinja2.sandbox import SandboxedEnvironment
 
 from sqlfluff.core.config import FluffConfig
@@ -28,7 +31,6 @@ from sqlfluff.core.templaters.base import (
 from sqlfluff.core.templaters.python import PythonTemplater
 from sqlfluff.core.templaters.slicers.tracer import JinjaAnalyzer
 
-
 # Instantiate the templater logger
 templater_logger = logging.getLogger("sqlfluff.templater")
 
@@ -146,12 +148,18 @@ class JinjaTemplater(PythonTemplater):
             os.path.join(library_path, "..") if is_library_module else library_path
         )
 
-        for loader, module_name, is_pkg in pkgutil.walk_packages([walk_path]):
+        for module_finder, module_name, _ in pkgutil.walk_packages([walk_path]):
             # skip other modules that can be near module_dir
             if is_library_module and not module_name.startswith(library_module_name):
                 continue
 
-            module = loader.find_module(module_name).load_module(module_name)
+            # import_module is deprecated as of python 3.4. This follows roughly
+            # the guidance of the python docs:
+            # https://docs.python.org/3/library/importlib.html#approximating-importlib-import-module
+            spec = module_finder.find_spec(module_name)
+            module = importlib.util.module_from_spec(spec)
+            sys.modules[module_name] = module
+            spec.loader.exec_module(module)
 
             if "." in module_name:  # nested modules have `.` in module_name
                 *module_path, last_module_name = module_name.split(".")
@@ -259,12 +267,15 @@ class JinjaTemplater(PythonTemplater):
             loader = SafeFileSystemLoader(macros_path or [])
         else:
             loader = FileSystemLoader(macros_path) if macros_path else None
+        extensions = ["jinja2.ext.do"]
+        if self._apply_dbt_builtins(config):
+            extensions.append(DBTTestExtension)
 
         return SandboxedEnvironment(
             keep_trailing_newline=True,
             # The do extension allows the "do" directive
             autoescape=False,
-            extensions=["jinja2.ext.do"],
+            extensions=extensions,
             loader=loader,
         )
 
@@ -279,6 +290,13 @@ class JinjaTemplater(PythonTemplater):
                     return result
         return None
 
+    def _apply_dbt_builtins(self, config: FluffConfig) -> bool:
+        if config:
+            return config.get_section(
+                (self.templater_selector, self.name, "apply_dbt_builtins")
+            )
+        return False
+
     def get_context(self, fname=None, config=None, **kw) -> Dict:
         """Get the templating context from the config."""
         # Load the context
@@ -288,12 +306,13 @@ class JinjaTemplater(PythonTemplater):
         if config:
             # first make libraries available in the context
             # so they can be used by the macros too
-            live_context.update(self._extract_libraries_from_config(config=config))
+            libraries = self._extract_libraries_from_config(config=config)
+            live_context.update(libraries)
 
-            apply_dbt_builtins = config.get_section(
-                (self.templater_selector, self.name, "apply_dbt_builtins")
-            )
-            if apply_dbt_builtins:
+            if libraries.get("SQLFLUFF_JINJA_FILTERS"):
+                env.filters.update(libraries.get("SQLFLUFF_JINJA_FILTERS"))
+
+            if self._apply_dbt_builtins(config):
                 # This feels a bit wrong defining these here, they should probably
                 # be configurable somewhere sensible. But for now they're not.
                 # TODO: Come up with a better solution.
@@ -503,7 +522,9 @@ class JinjaTemplater(PythonTemplater):
         if make_template is None:
             # make_template() was not provided. Use the base class
             # implementation instead.
-            return super().slice_file(raw_str, templated_str, config, **kwargs)
+            return super().slice_file(
+                raw_str, templated_str, config, **kwargs
+            )  # pragma: no cover
 
         templater_logger.info("Slicing File Template")
         templater_logger.debug("    Raw String: %r", raw_str)
@@ -596,3 +617,19 @@ class DummyUndefined(jinja2.Undefined):
 
     def __iter__(self):
         return [self].__iter__()
+
+
+class DBTTestExtension(Extension):
+    """Jinja extension to handle the dbt test tag."""
+
+    tags = {"test"}
+
+    def parse(self, parser):
+        """Parses out the contents of the test tag."""
+        node = jinja2.nodes.Macro(lineno=next(parser.stream).lineno)
+        test_name = parser.parse_assign_target(name_only=True).name
+
+        parser.parse_signature(node)
+        node.name = f"test_{test_name}"
+        node.body = parser.parse_statements(("name:endtest",), drop_needle=True)
+        return node
