@@ -6,15 +6,16 @@ from typing import Dict, Optional, Tuple
 
 
 from sqlfluff.core.errors import SQLTemplaterError
+from sqlfluff.core.slice_helpers import offset_slice
 
 from sqlfluff.core.templaters.base import (
     RawFileSlice,
     TemplatedFile,
     TemplatedFileSlice,
+    large_file_check,
+    RawTemplater,
 )
 
-from sqlfluff.core.templaters.base import RawTemplater
-
 # Instantiate the templater logger
 templater_logger = logging.getLogger("sqlfluff.templater")
 
@@ -35,6 +36,8 @@ KNOWN_STYLES = {
     "dollar": regex.compile(
         r"(?<![:\w\x5c])\${?(?P<param_name>[\w_]+)}?", regex.UNICODE
     ),
+    # e.g. USE ${flyway:database}.schema_name;
+    "flyway_var": regex.compile(r"\${(?P<param_name>\w+[:\w_]+)}", regex.UNICODE),
     # e.g. WHERE bla = ?
     "question_mark": regex.compile(r"(?<![:\w\x5c])\?", regex.UNICODE),
     # e.g. WHERE bla = $3 or WHERE bla = ${3}
@@ -110,6 +113,7 @@ class PlaceholderTemplater(RawTemplater):
 
         return live_context
 
+    @large_file_check
     def process(
         self, *, in_str: str, fname: str, config=None, formatter=None
     ) -> Tuple[Optional[TemplatedFile], list]:
@@ -162,10 +166,9 @@ class PlaceholderTemplater(RawTemplater):
                 TemplatedFileSlice(
                     slice_type="literal",
                     source_slice=slice(last_pos_raw, span[0], None),
-                    templated_slice=slice(
+                    templated_slice=offset_slice(
                         last_pos_templated,
-                        last_pos_templated + last_literal_length,
-                        None,
+                        last_literal_length,
                     ),
                 )
             )
@@ -182,10 +185,8 @@ class PlaceholderTemplater(RawTemplater):
             template_slices.append(
                 TemplatedFileSlice(
                     slice_type="templated",
-                    source_slice=slice(span[0], span[1], None),
-                    templated_slice=slice(
-                        start_template_pos, start_template_pos + len(replacement), None
-                    ),
+                    source_slice=slice(span[0], span[1]),
+                    templated_slice=offset_slice(start_template_pos, len(replacement)),
                 )
             )
             raw_slices.append(
@@ -204,11 +205,10 @@ class PlaceholderTemplater(RawTemplater):
             template_slices.append(
                 TemplatedFileSlice(
                     slice_type="literal",
-                    source_slice=slice(last_pos_raw, len(in_str), None),
-                    templated_slice=slice(
+                    source_slice=slice(last_pos_raw, len(in_str)),
+                    templated_slice=offset_slice(
                         last_pos_templated,
-                        last_pos_templated + (len(in_str) - last_pos_raw),
-                        None,
+                        (len(in_str) - last_pos_raw),
                     ),
                 )
             )
