@@ -44,7 +44,6 @@ INSERT_ONLY
 INTERSECT
 INTO
 IS
-ISSUE
 JOIN
 LATERAL
 LEFT
@@ -100,8 +99,8 @@ ACCOUNTS
 ADD
 ADMIN
 AFTER
-ALLOW_DUPLICATE
 ALLOWED_IP_LIST
+ALLOW_DUPLICATE
 ALLOW_OVERLAPPING_EXECUTION
 API
 API_INTEGRATION
@@ -114,13 +113,13 @@ ATTACH
 AUTHORIZATION
 AUTHORIZATIONS
 AUTO
+AUTOINCREMENT
 AUTO_COMPRESS
 AUTO_INCREMENT
 AUTO_INGEST
 AUTO_REFRESH
 AUTO_RESUME
 AUTO_SUSPEND
-AUTOINCREMENT
 AVRO
 AWS_KEY_ID
 AWS_ROLE
@@ -154,11 +153,12 @@ CALLED
 CALLER
 CASCADE
 CASE
+CASES
 CASE_INSENSITIVE
 CASE_SENSITIVE
 CHAIN
-CHANGE_TRACKING
 CHANGES
+CHANGE_TRACKING
 CHARACTER
 CLONE
 CLUSTER
@@ -193,9 +193,10 @@ CURRENT_VERSION
 CURRENT_WAREHOUSE
 CYCLE
 DATA
-DATA_RETENTION_TIME_IN_DAYS
 DATABASE
 DATABASES
+DATA_FORMAT
+DATA_RETENTION_TIME_IN_DAYS
 DATE
 DATE_FORMAT
 DAYS_TO_EXPIRY
@@ -212,12 +213,13 @@ DEFLATE
 DELEGATED
 DESC
 DESCRIBE
+DETAILED_OUTPUT
 DIRECTION
 DIRECTORY
 DISABLE
+DISABLED
 DISABLE_AUTO_CONVERT
 DISABLE_SNOWFLAKE_DATA
-DISABLED
 DISPLAY_NAME
 DOMAIN
 DOUBLE
@@ -226,13 +228,13 @@ EMAIL
 EMPTY
 EMPTY_FIELD_AS_NULL
 ENABLE
-ENABLE_OCTAL
 ENABLED
+ENABLE_OCTAL
 ENCODING
 ENCRYPTION
 END
-ENFORCE_LENGTH
 ENFORCED
+ENFORCE_LENGTH
 ENUM
 ERROR_INTEGRATION
 ERROR_ON_COLUMN_COUNT_MISMATCH
@@ -240,6 +242,7 @@ ESCAPE
 ESCAPE_UNENCLOSED_FIELD
 EXCEPT
 EXCHANGE
+EXCLUDE
 EXECUTE
 EXECUTION
 EXPLAIN
@@ -250,9 +253,9 @@ FETCH
 FIELD_DELIMITER
 FIELD_OPTIONALLY_ENCLOSED_BY
 FILE
+FILES
 FILE_EXTENSION
 FILE_FORMAT
-FILES
 FILTER
 FINAL
 FIRST
@@ -260,8 +263,8 @@ FIRST_NAME
 FORCE
 FOREIGN
 FORMAT
-FORMAT_NAME
 FORMATS
+FORMAT_NAME
 FUNCTION
 FUNCTIONS
 FUTURE
@@ -275,6 +278,8 @@ GRANTED
 GRANTS
 GROUPING
 GZIP
+HANDLER
+HEADER
 HEADERS
 HEX
 HISTORY
@@ -286,15 +291,19 @@ IGNORE_UTF8_ERRORS
 IMMEDIATE
 IMMUTABLE
 IMPORT
+IMPORTS
 IMPORTED
+INCLUDE_QUERY_ID
 INDEX
+INFORMATION
 INITIALLY
 INITIALLY_SUSPENDED
-INFORMATION
 INPUT
 INTEGRATION
 INTEGRATIONS
 INTERVAL
+ISSUE
+JAVA
 JAVASCRIPT
 JSON
 KEY
@@ -320,23 +329,24 @@ MANAGED
 MASKING
 MASTER_KEY
 MATCH
-MATCH_BY_COLUMN_NAME
 MATCHED
 MATCHES
+MATCH_BY_COLUMN_NAME
 MATERIALIZED
+MAXVALUE
 MAX_BATCH_ROWS
 MAX_CLUSTER_COUNT
 MAX_CONCURRENCY_LEVEL
 MAX_DATA_EXTENSION_TIME_IN_DAYS
+MAX_FILE_SIZE
 MAX_SIZE
-MAXVALUE
 MEASURES
 MERGE
 MIDDLE_NAME
-MIN_CLUSTER_COUNT
 MINS_TO_BYPASS_MFA
 MINS_TO_UNLOCK
 MINVALUE
+MIN_CLUSTER_COUNT
 ML
 MODEL
 MODIFIED_AFTER
@@ -356,15 +366,15 @@ NOORDER
 NOTIFICATION
 NOTIFICATION_INTEGRATION
 NOTIFICATION_PROVIDER
-NULL_IF
 NULLS
+NULL_IF
 OBJECT
 OBJECTS
 OFFSET
 OMIT
-ON_ERROR
 ONE
 ONLY
+ON_ERROR
 OPERATE
 OPTIMIZATION
 OPTION
@@ -379,6 +389,7 @@ OVERRIDE
 OVERWRITE
 OWNER
 OWNERSHIP
+PACKAGES
 PARALLEL
 PARAMETERS
 PARQUET
@@ -386,11 +397,12 @@ PARTITION
 PASSWORD
 PAST
 PATTERN
+FIELD_OPTIONALITY_ENCLOSED_BY
 PER
 PERMUTE
 PIPE
-PIPE_EXECUTION_PAUSED
 PIPES
+PIPE_EXECUTION_PAUSED
 PIVOT
 POLICIES
 POLICY
@@ -406,6 +418,7 @@ PROCEDURES
 PUBLIC
 PURGE
 PUT
+PYTHON
 QUERIES
 QUEUE
 RANGE
@@ -414,8 +427,8 @@ READ
 RECLUSTER
 RECORD_DELIMITER
 RECURSIVE
-REFERENCE_USAGE
 REFERENCES
+REFERENCE_USAGE
 REFRESH
 REFRESH_ON_CREATE
 REGIONS
@@ -425,6 +438,7 @@ REPEATABLE
 REPLACE
 REPLACE_INVALID_CHARACTERS
 REPLICATION
+REQUEST_TRANSLATOR
 RESET
 RESOURCE
 RESOURCE_MONITOR
@@ -434,10 +448,10 @@ RESTRICT
 RESTRICTIONS
 RESULT
 RESUME
+RETURNS
 RETURN_ALL_ERRORS
 RETURN_ERRORS
 RETURN_FAILED_ONLY
-RETURNS
 RM
 ROLE
 ROLES
@@ -448,8 +462,8 @@ ROUTINES
 ROW
 RSA_PUBLIC_KEY
 RSA_PUBLIC_KEY_2
-REQUEST_TRANSLATOR
 RUNNING
+RUNTIME_VERSION
 S3
 SCALING_POLICY
 SCHEDULE
@@ -472,6 +486,7 @@ SHARES
 SHARE_RESTRICTIONS
 SHOW
 SHOW_INITIAL_ROWS
+SINGLE
 SIZE_LIMIT
 SKIP
 SKIP_BLANK_LINES
@@ -485,9 +500,9 @@ SNOWFLAKE_SSE
 SOURCE_COMPRESSION
 SQL
 STAGE
+STAGES
 STAGE_COPY_OPTIONS
 STAGE_FILE_FORMAT
-STAGES
 STANDARD
 STARTS
 STATEMENT
@@ -506,6 +521,7 @@ STRIP_NULL_VALUES
 STRIP_OUTER_ARRAY
 STRIP_OUTER_ELEMENT
 SUBPATH
+SUPPORT
 SUSPEND
 SUSPENDED
 SWAP
@@ -515,6 +531,7 @@ TABLES
 TABLESPACE
 TABULAR
 TAG
+TARGET_PATH
 TASK
 TASKS
 TEMP
@@ -523,9 +540,9 @@ TEMPORARY
 TERSE
 TEXT
 TIME
-TIME_FORMAT
 TIMESTAMP
 TIMESTAMP_FORMAT
+TIME_FORMAT
 TOP
 TRANSACTION
 TRANSACTIONS
@@ -543,11 +560,11 @@ URL
 US
 USAGE
 USE
-USE_ANY_ROLE
 USER
+USERS
 USER_TASK_MANAGED_INITIAL_WAREHOUSE_SIZE
 USER_TASK_TIMEOUT_MS
-USERS
+USE_ANY_ROLE
 UTF8
 VALIDATE_UTF8
 VALIDATION_MODE
@@ -561,9 +578,9 @@ VIEWS
 VOLATILE
 WAIT_FOR_COMPLETION
 WAREHOUSE
+WAREHOUSES
 WAREHOUSE_SIZE
 WAREHOUSE_TYPE
-WAREHOUSES
 WINDOW
 WITH
 WITHIN
